************************************
How to setup and distribute a plugin
************************************


Setup
=====


Distribution
============

Template `setup.py <gradient_descent_algo_setup>`_
TODO

.. _gradient_descent_algo_setup: https://github.com/epistimio/orion/blob/master/tests/functional/gradient_descent_algo/setup.py
